#!/usr/bin/env python
# coding: utf-8

from setuptools import setup

setup(name='hello_world_client_fuck',
      version='0.0.8',
      author='hello world',
      include_package_data=True,
      zip_safe=False,
      url="https://pypi.org/",
      author_email='',
      python_requires=">=3.3",
      packages=['src'],
      license="MIT",
      install_requires=[])
